@@ -174,9 +174,18 @@ sub isValidText {
 }
 
 sub isValidTime {
-   my ($self, $v) = @_; my $pat = '\A \d\d : \d\d (?: : \d\d )? \z';
+   my ($self, $v) = @_; my $pat = '\A (\d\d ): (\d\d) (?: : (\d\d) )? \z';
 
-   return $self->isMatchingRegex( $v, $pat ) ? TRUE : FALSE;
+   $self->isMatchingRegex( $v, $pat ) or return FALSE;
+
+   my ($hours, $minutes, $seconds) = $v =~ m{ $pat }msx;
+
+   ($hours   >= 0 and $hours   <= 23) or return FALSE;
+   ($minutes >= 0 and $minutes <= 59) or return FALSE;
+
+   defined $seconds or return TRUE;
+
+   return ($seconds >= 0 && $seconds <= 59) ? TRUE : FALSE;
 }
 
 1;
@@ -360,7 +369,7 @@ method
 
 =head2 Date
 
-If the C<str2time> method in the L<CatalystX::Usul::Class::Time>
+If the C<str2time> method in the L<Class::Usul::Time>
 module can parse the supplied value then it is deemed to be a valid
 date
 
