@@ -10,7 +10,7 @@ extends q(Data::Validation::Constraints);
 
 EXCEPTION_CLASS->add_exception( 'ValidEmail', {
    parents => [ 'InvalidParameter' ],
-   error   => 'Parameter [_1] value [_2] is not a valid email address' } );
+   error   => 'Parameter [_1] is not a valid email address' } );
 
 sub validate {
    return Email::Valid->address( $_[ 1 ] ) ? TRUE : FALSE;
