@@ -9,7 +9,7 @@ extends q(Data::Validation::Constraints);
 
 EXCEPTION_CLASS->add_exception( 'ValidPath', {
    parents => [ 'InvalidParameter' ],
-   error   => 'Parameter [_1] value [_2] is not a valid pathname' } );
+   error   => 'Parameter [_1] is not a valid pathname' } );
 
 sub validate {
    my ($self, $val) = @_; return $val !~ m{ [;&*{} ] }mx ? TRUE : FALSE;
