@@ -3,6 +3,7 @@ package Data::Validation::Exception;
 use namespace::autoclean;
 
 use Unexpected::Functions qw( has_exception );
+use Unexpected::Types     qw( HashRef SimpleStr );
 use Moo;
 
 extends q(Unexpected);
@@ -18,22 +19,26 @@ has_exception 'Allowed' => parents => [ 'InvalidParameter' ],
    error   => 'Parameter [_1] is not in the list of allowed values';
 
 has_exception 'BetweenValues' => parents => [ 'InvalidParameter' ],
-   error   => 'Parameter [_1] is not in range';
+   error   => 'Parameter [_1] is not in range',
+   explain => 'Must be greater than {min_value} and less than {max_value}';
 
 has_exception 'EqualTo' => parents => [ 'InvalidParameter' ],
-   error   => 'Parameter [_1] is not equal to the required value';
+   error   => 'Parameter [_1] is not equal to the required value',
+   explain => 'Must equal {value}';
 
 has_exception 'FieldComparison' => parents => [ 'InvalidParameter' ],
    error   => 'Field [_1] does not [_2] field [_3]';
 
 has_exception 'Hexadecimal' => parents => [ 'InvalidParameter' ],
-   error   => 'Parameter [_1] is not a hexadecimal number';
+   error   => 'Parameter [_1] is not a hexadecimal number',
+   explain => 'Hexadecimal numbers can only contain the characters 0-9a-f';
 
 has_exception 'Mandatory' => parents => [ 'InvalidParameter' ],
    error   => 'Parameter [_1] is mandatory';
 
 has_exception 'MatchingRegex' => parents => [ 'InvalidParameter' ],
-   error   => 'Parameter [_1] does not match the required regex';
+   error   => 'Parameter [_1] does not match the required regex',
+   explain => 'Must match the pattern {pattern}';
 
 has_exception 'MatchingType' => parents => [ 'InvalidParameter' ],
    error   => 'Parameter [_1] does not of the required type [_3]';
@@ -42,28 +47,34 @@ has_exception 'Printable' => parents => [ 'InvalidParameter' ],
    error   => 'Parameter [_1] value is not a printable character';
 
 has_exception 'SimpleText' => parents => [ 'InvalidParameter' ],
-   error   => 'Parameter [_1] is not simple text';
+   error   => 'Parameter [_1] is not simple text',
+   explain => 'Must match the pattern [a-zA-Z0-9_ \-\.]+';
 
 has_exception 'ValidHostname' => parents => [ 'InvalidParameter' ],
    error   => 'Parameter [_1] is not a hostname';
 
 has_exception 'ValidIdentifier' => parents => [ 'InvalidParameter' ],
-   error   => 'Parameter [_1] is not a valid identifier';
+   error   => 'Parameter [_1] is not a valid identifier',
+   explain => 'Must match the pattern [a-zA-Z_] \w*';
 
 has_exception 'ValidInteger' => parents => [ 'InvalidParameter' ],
    error   => 'Parameter [_1] is not a valid integer';
 
 has_exception 'ValidLength' => parents => [ 'InvalidParameter' ],
-   error   => 'Parameter [_1] has an invalid length';
+   error   => 'Parameter [_1] has an invalid length',
+   explain => 'Must be greater than {min_length} and less '
+            . 'than {max_length} characters long';
 
 has_exception 'ValidNumber' => parents => [ 'InvalidParameter' ],
    error   => 'Parameter [_1] is not a valid number';
 
 has_exception 'ValidText' => parents => [ 'InvalidParameter' ],
-   error   => 'Parameter [_1] is not valid text';
+   error   => 'Parameter [_1] is not valid text',
+   explain => 'Must match the pattern [\t\n !\"#%&\'\(\)\*\+\,\-\./0-9:;=\?@A-Z\[\]_a-z\|\~]+';
 
 has_exception 'ValidTime' => parents => [ 'InvalidParameter' ],
-   error   => 'Parameter [_1] is not a valid time';
+   error   => 'Parameter [_1] is not a valid time',
+   explain => 'Must match the pattern (\d\d ): (\d\d) (?: : (\d\d) )?';
 
 has_exception 'KnownType' => parents => [ $class ],
    error   => 'Type constraint [_1] is unknown';
@@ -73,6 +84,25 @@ has_exception 'ValidationErrors' => parents => [ $class ],
 
 has '+class' => default => $class;
 
+has 'constraints' => is => 'lazy', isa => HashRef, default => sub { {} };
+
+has '_explain' => is => 'lazy', isa => SimpleStr, default => q(),
+   init_arg => 'explain';
+
+sub explain {
+   my $self = shift; my $text = $self->_explain;
+
+   0 > index $text, '{' and return $text;
+
+   # Expand named parameters of the form {param_name}
+   my %args = %{ $self->constraints };
+   my $re = join '|', map { quotemeta $_ } keys %args;
+
+   $text =~ s{ \{($re)\} }{ defined $args{ $1 } ? $args{ $1 } : "{${1}?}" }egmx;
+
+   return $text;
+}
+
 1;
 
 __END__
@@ -137,7 +167,9 @@ Defines the following exceptions;
 
 =head1 Subroutines/Methods
 
-None
+=head2 C<explain>
+
+Returns an explanation of the validation error
 
 =head1 Diagnostics
 
